@@ -46,9 +46,6 @@
 int contact_schedd_interval = 20;
 
 
-// Do we use XML-formatted classads when talking to our invoker
-bool useXMLClassads = false;
-
 // What is the subject name of our jobs' GSI proxies? This is taken from
 // INITIALIZE_FROM_FILE and is added to GSI_DAEMON_NAME
 char *proxySubjectName = NULL;
@@ -563,10 +560,12 @@ doContactSchedd()
 
 	// Try connecting to the queue
 	Qmgr_connection * qmgr_connection;
-	
-	if ((qmgr_connection = ConnectQ(dc_schedd.addr(), QMGMT_TIMEOUT, false, NULL, NULL, dc_schedd.version() )) == NULL) {
+
+	errstack.clear();
+	if ((qmgr_connection = ConnectQ(dc_schedd.addr(), QMGMT_TIMEOUT, false, &errstack, NULL, dc_schedd.version() )) == NULL) {
 		error = TRUE;
-		formatstr( error_msg, "Error connecting to schedd %s", ScheddAddr );
+		formatstr( error_msg, "Error connecting to schedd %s: %s", ScheddAddr,
+				   errstack.getFullText().c_str() );
 		dprintf( D_ALWAYS, "%s\n", error_msg.c_str() );
 	} else {
 		errno = 0;
@@ -574,6 +573,11 @@ doContactSchedd()
 		if ( errno == ETIMEDOUT ) {
 			failure_line_num = __LINE__;
 			failure_errno = errno;
+			dprintf( D_ALWAYS, "Network error talking to schedd at line %d in "
+					 "doContactSchedd(), probably an authorization failure\n",
+					 failure_line_num );
+			formatstr( error_msg, "Network error talking to schedd, "
+					   "probably an authorization failure" );
 			goto contact_schedd_disconnect;
 		}
 	}
@@ -710,8 +714,6 @@ update_report_result:
 	command_queue.Rewind();
 	while (command_queue.Next(current_command)) {
 		
-		error = FALSE;
-
 		if (current_command->status != SchedDRequest::SDCS_NEW)
 			continue;
 
@@ -724,10 +726,7 @@ update_report_result:
 		}
 
 		std::string success_job_ids="";
-		if (qmgr_connection == NULL) {
-			formatstr( error_msg, "Error connecting to schedd %s", ScheddAddr );
-			error = TRUE;
-		} else {
+		if (qmgr_connection != NULL) {
 			error = FALSE;
 			errno = 0;
 			BeginTransaction();
@@ -1027,6 +1026,18 @@ submit_report_result:
 		
 	// STATUS_CONSTRAINED
 	command_queue.Rewind();
+	if (qmgr_connection != NULL)
+	{
+		DisconnectQ(qmgr_connection, FALSE);
+		if ((qmgr_connection = ConnectQ(dc_schedd.addr(), QMGMT_TIMEOUT, true, &errstack, NULL, dc_schedd.version() )) == NULL)
+		{
+			formatstr(error_msg, "Error connecting to schedd %s for read-only commands: %s", ScheddAddr, errstack.getFullText().c_str());
+			dprintf(D_ALWAYS, "%s\n", error_msg.c_str());
+			failure_line_num = __LINE__;
+			failure_errno = errno;
+			goto contact_schedd_disconnect;
+		}
+	}
 	while (command_queue.Next(current_command)) {
 
 		if (current_command->status != SchedDRequest::SDCS_NEW)
@@ -1043,8 +1054,6 @@ submit_report_result:
 		if (qmgr_connection != NULL) {
 			SimpleList <std::string *> matching_ads;
 
-			error = FALSE;
-			
 			ClassAd *next_ad;
 			ClassAdList adlist;
 				// Only use GetAllJobsByConstraint if remote schedd is
@@ -1075,14 +1084,8 @@ submit_report_result:
 			adlist.Rewind();
 			while( (next_ad=adlist.Next()) ) {
 				std::string * da_buffer = new std::string();	// Use a ptr to avoid excessive copying
-				if ( useXMLClassads ) {
-					classad::ClassAdXMLUnParser unparser;
-					unparser.SetCompactSpacing( true );
-					unparser.Unparse( *da_buffer, next_ad );
-				} else {
-					classad::ClassAdUnParser unparser;
-					unparser.Unparse( *da_buffer, next_ad );
-				}
+				classad::ClassAdUnParser unparser;
+				unparser.Unparse( *da_buffer, next_ad );
 				matching_ads.Append (da_buffer);
 			}
 			if ( errno == ETIMEDOUT ) {
@@ -1141,15 +1144,17 @@ submit_report_result:
 			// incomplete commands and mark them as failed.
 			// TODO Consider retrying these commands, rather than
 			//   immediately marking them as failed.
-		if ( failure_errno == ETIMEDOUT ) {
-			dprintf( D_ALWAYS, "Timed out talking to schedd at line %d in "
-					 "doContactSchedd()\n", failure_line_num );
-			formatstr( error_msg, "Timed out talking to schedd" );
-		} else {
-			dprintf( D_ALWAYS, "Error talking to schedd at line %d in "
-					 "doContactSchedd(), errno=%d (%s)\n", failure_line_num,
-					 failure_errno, strerror(failure_errno) );
-			formatstr( error_msg, "Error talking to schedd" );
+		if ( error_msg.empty() ) {
+			if ( failure_errno == ETIMEDOUT ) {
+				dprintf( D_ALWAYS, "Network error talking to schedd at line %d in "
+						 "doContactSchedd()\n", failure_line_num );
+				formatstr( error_msg, "Network error talking to schedd" );
+			} else {
+				dprintf( D_ALWAYS, "Error talking to schedd at line %d in "
+						 "doContactSchedd(), errno=%d (%s)\n", failure_line_num,
+						 failure_errno, strerror(failure_errno) );
+				formatstr( error_msg, "Error talking to schedd" );
+			}
 		}
 		command_queue.Rewind();
 		while (command_queue.Next(current_command)) {
@@ -1528,20 +1533,11 @@ get_job_id (const char * s, int * cluster_id, int * proc_id) {
 // String (XML) -> classad
 int
 get_class_ad (const char * s, ClassAd ** class_ad) {
-	if ( useXMLClassads ) {
-		classad::ClassAdXMLParser parser;
-		*class_ad = new ClassAd;
-		if ( !parser.ParseClassAd( s, **class_ad ) ) {
-			delete *class_ad;
-			*class_ad = NULL;
-		}
-	} else {
-		classad::ClassAdParser parser;
-		*class_ad = new ClassAd;
-		if ( !parser.ParseClassAd( s, **class_ad ) ) {
-			delete *class_ad;
-			*class_ad = NULL;
-		}
+	classad::ClassAdParser parser;
+	*class_ad = new ClassAd;
+	if ( !parser.ParseClassAd( s, **class_ad ) ) {
+		delete *class_ad;
+		*class_ad = NULL;
 	}
 	if ( *class_ad ) {
 		return TRUE;
