@@ -643,7 +643,7 @@ Daemon::startSubCommand( int cmd, int subcmd, Sock* sock, int timeout, CondorErr
 	case StartCommandContinue: //impossible!
 		break;
 	}
-	EXCEPT("startCommand(nonblocking=false) returned an unexpected result: %d\n",rc);
+	EXCEPT("startCommand(nonblocking=false) returned an unexpected result: %d",rc);
 	return false;
 }
 
@@ -668,7 +668,7 @@ Daemon::startSubCommand( int cmd, int subcmd, Stream::stream_type st, int timeou
 	case StartCommandContinue: //impossible!
 		break;
 	}
-	EXCEPT("startCommand(blocking=true) returned an unexpected result: %d\n",rc);
+	EXCEPT("startCommand(blocking=true) returned an unexpected result: %d",rc);
 	return NULL;
 }
 
@@ -693,7 +693,7 @@ Daemon::startCommand( int cmd, Stream::stream_type st, int timeout, CondorError*
 	case StartCommandContinue: //impossible!
 		break;
 	}
-	EXCEPT("startCommand(blocking=true) returned an unexpected result: %d\n",rc);
+	EXCEPT("startCommand(blocking=true) returned an unexpected result: %d",rc);
 	return NULL;
 }
 
@@ -732,7 +732,7 @@ Daemon::startCommand( int cmd, Sock* sock, int timeout, CondorError *errstack, c
 	case StartCommandContinue: //impossible!
 		break;
 	}
-	EXCEPT("startCommand(nonblocking=false) returned an unexpected result: %d\n",rc);
+	EXCEPT("startCommand(nonblocking=false) returned an unexpected result: %d",rc);
 	return false;
 }
 
