@@ -347,6 +347,11 @@ DCSchedd::receiveJobSandbox(const char* constraint, CondorError * errstack, int
 	if( ! rsock.connect(_addr) ) {
 		dprintf( D_ALWAYS, "DCSchedd::receiveJobSandbox: "
 				 "Failed to connect to schedd (%s)\n", _addr );
+		if ( errstack ) {
+			errstack->push( "DCSchedd::receiveJobSandbox",
+							CEDAR_ERR_CONNECT_FAILED,
+							"Failed to connect to schedd" );
+		}
 		return false;
 	}
 	if ( use_new_command ) {
@@ -374,6 +379,17 @@ DCSchedd::receiveJobSandbox(const char* constraint, CondorError * errstack, int
 		return false;
 	}
 
+	// If we don't already know the version of the schedd, try to pull
+	// it out of CEDAR. It's important to know for the FileTransfer
+	// protocol.
+	const CondorVersionInfo *peer_version = rsock.get_peer_version();
+	if ( _version == NULL && peer_version != NULL ) {
+		_version = peer_version->get_version_string();
+	}
+	if ( _version == NULL ) {
+		dprintf( D_ALWAYS, "Unable to determine schedd version for file transfer\n" );
+	}
+
 	rsock.encode();
 
 		// Send our version if using the new command
@@ -384,6 +400,11 @@ DCSchedd::receiveJobSandbox(const char* constraint, CondorError * errstack, int
 		if ( !rsock.code(my_version) ) {
 			dprintf(D_ALWAYS,"DCSchedd:receiveJobSandbox: "
 					"Can't send version string to the schedd\n");
+			if ( errstack ) {
+				errstack->push( "DCSchedd::receiveJobSandbox",
+								CEDAR_ERR_PUT_FAILED,
+								"Can't send version string to the schedd" );
+			}
 			free( my_version );
 			return false;
 		}
@@ -396,6 +417,11 @@ DCSchedd::receiveJobSandbox(const char* constraint, CondorError * errstack, int
 		free( nc_constraint );
 		dprintf(D_ALWAYS,"DCSchedd:receiveJobSandbox: "
 				"Can't send JobAdsArrayLen to the schedd\n");
+		if ( errstack ) {
+			errstack->push( "DCSchedd::receiveJobSandbox",
+							CEDAR_ERR_PUT_FAILED,
+							"Can't send JobAdsArrayLen to the schedd" );
+		}
 		return false;
 	}
 	free( nc_constraint );
@@ -403,7 +429,7 @@ DCSchedd::receiveJobSandbox(const char* constraint, CondorError * errstack, int
 	if ( !rsock.end_of_message() ) {
 		std::string errmsg;
 		formatstr(errmsg,
-				"Can't send initial message (version + constraint) to schedd (%s)",
+				"Can't send initial message (version + constraint) to schedd (%s), probably an authorization failure",
 				_addr);
 
 		dprintf(D_ALWAYS,"DCSchedd::receiveJobSandbox: %s\n", errmsg.c_str());
@@ -664,11 +690,19 @@ DCSchedd::requestSandboxLocation(int direction,
 		if (!JobAdsArray[i]->LookupInteger(ATTR_CLUSTER_ID,cluster)) {
 			dprintf(D_ALWAYS,"DCSchedd:requestSandboxLocation: "
 					"Job ad %d did not have a cluster id\n",i);
+			if ( errstack ) {
+				errstack->pushf( "DCSchedd::requestSandboxLocation", 1,
+								 "Job ad %d did not have a cluster id", i );
+			}
 			return false;
 		}
 		if (!JobAdsArray[i]->LookupInteger(ATTR_PROC_ID,proc)) {
 			dprintf(D_ALWAYS,"DCSchedd:requestSandboxLocation(): "
 					"Job ad %d did not have a proc id\n",i);
+			if ( errstack ) {
+				errstack->pushf( "DCSchedd::requestSandboxLocation", 1,
+								 "Job ad %d did not have a proc id", i );
+			}
 			return false;
 		}
 		
@@ -696,6 +730,10 @@ DCSchedd::requestSandboxLocation(int direction,
 			dprintf(D_ALWAYS, "DCSchedd::requestSandboxLocation(): "
 				"Can't make a request for a sandbox with an unknown file "
 				"transfer protocol!");
+			if ( errstack ) {
+				errstack->push( "DCSchedd::requestSandboxLocation", 1,
+								"Unknown file transfer protocol" );
+			}
 			return false;
 			break;
 	}
@@ -734,6 +772,10 @@ DCSchedd::requestSandboxLocation(int direction, MyString &constraint,
 			dprintf(D_ALWAYS, "DCSchedd::requestSandboxLocation(): "
 				"Can't make a request for a sandbox with an unknown file "
 				"transfer protocol!");
+			if ( errstack ) {
+				errstack->push( "DCSchedd::requestSandboxLocation", 1,
+								"Unknown file transfer protocol" );
+			}
 			return false;
 			break;
 	}
@@ -759,6 +801,11 @@ DCSchedd::requestSandboxLocation(ClassAd *reqad, ClassAd *respad,
 	if( ! rsock.connect(_addr) ) {
 		dprintf( D_ALWAYS, "DCSchedd::requestSandboxLocation(): "
 				 "Failed to connect to schedd (%s)\n", _addr );
+		if ( errstack ) {
+			errstack->push( "DCSchedd::requestSandboxLocation",
+							CEDAR_ERR_CONNECT_FAILED,
+							"Failed to connect to schedd" );
+		}
 		return false;
 	}
 	if( ! startCommand(REQUEST_SANDBOX_LOCATION, (Sock*)&rsock, 0,
@@ -799,6 +846,11 @@ DCSchedd::requestSandboxLocation(ClassAd *reqad, ClassAd *respad,
 	if (putClassAd(&rsock, *reqad) != 1) {
 		dprintf(D_ALWAYS,"DCSchedd:requestSandboxLocation(): "
 				"Can't send reqad to the schedd\n");
+		if ( errstack ) {
+			errstack->push( "DCSchedd::requestSandboxLocation",
+							CEDAR_ERR_PUT_FAILED,
+							"Can't send reqad to the schedd" );
+		}
 		return false;
 	}
 	rsock.end_of_message();
@@ -825,6 +877,11 @@ DCSchedd::requestSandboxLocation(ClassAd *reqad, ClassAd *respad,
 	if (getClassAd(&rsock, status_ad) == false) {
 		dprintf(D_ALWAYS, "Schedd closed connection to me. Aborting sandbox "
 			"submission.\n");
+		if ( errstack ) {
+			errstack->push( "DCSchedd::requestSandboxLocation",
+							CEDAR_ERR_GET_FAILED,
+							"Schedd closed connection" );
+		}
 		return false;
 	}
 	rsock.end_of_message();
@@ -862,7 +919,12 @@ DCSchedd::requestSandboxLocation(ClassAd *reqad, ClassAd *respad,
 	dprintf(D_ALWAYS, "Receiving response ad.\n");
 	if (getClassAd(&rsock, *respad) != true) {
 		dprintf(D_ALWAYS,"DCSchedd:requestSandboxLocation(): "
-				"Can't receive respond ad from the schedd\n");
+				"Can't receive response ad from the schedd\n");
+		if ( errstack ) {
+			errstack->push( "DCSchedd::requestSandboxLocation",
+							CEDAR_ERR_GET_FAILED,
+							"Can't receive response ad from the schedd" );
+		}
 		return false;
 	}
 	rsock.end_of_message();
@@ -933,6 +995,17 @@ DCSchedd::spoolJobFiles(int JobAdsArrayLen, ClassAd* JobAdsArray[], CondorError
 		return false;
 	}
 
+	// If we don't already know the version of the schedd, try to pull
+	// it out of CEDAR. It's important to know for the FileTransfer
+	// protocol.
+	const CondorVersionInfo *peer_version = rsock.get_peer_version();
+	if ( _version == NULL && peer_version != NULL ) {
+		_version = peer_version->get_version_string();
+	}
+	if ( _version == NULL ) {
+		dprintf( D_ALWAYS, "Unable to determine schedd version for file transfer\n" );
+	}
+
 	rsock.encode();
 
 		// Send our version if using the new command
@@ -943,6 +1016,11 @@ DCSchedd::spoolJobFiles(int JobAdsArrayLen, ClassAd* JobAdsArray[], CondorError
 		if ( !rsock.code(my_version) ) {
 			dprintf(D_ALWAYS,"DCSchedd:spoolJobFiles: "
 					"Can't send version string to the schedd\n");
+			if ( errstack ) {
+				errstack->push( "DCSchedd::spoolJobFiles",
+								CEDAR_ERR_PUT_FAILED,
+								"Can't send version string to the schedd" );
+			}
 			free( my_version );
 			return false;
 		}
@@ -953,13 +1031,18 @@ DCSchedd::spoolJobFiles(int JobAdsArrayLen, ClassAd* JobAdsArray[], CondorError
 	if ( !rsock.code(JobAdsArrayLen) ) {
 		dprintf(D_ALWAYS,"DCSchedd:spoolJobFiles: "
 				"Can't send JobAdsArrayLen to the schedd\n");
+		if ( errstack ) {
+			errstack->push( "DCSchedd::spoolJobFiles",
+							CEDAR_ERR_PUT_FAILED,
+							"Can't send JobAdsArrayLen to the schedd" );
+		}
 		return false;
 	}
 
 	if( !rsock.end_of_message() ) {
 		std::string errmsg;
 		formatstr(errmsg,
-				"Can't send initial message (version + count) to schedd (%s)",
+				"Can't send initial message (version + count) to schedd (%s), probably an authorization failure",
 				_addr);
 
 		dprintf(D_ALWAYS,"DCSchedd:spoolJobFiles: %s\n", errmsg.c_str());
@@ -979,11 +1062,19 @@ DCSchedd::spoolJobFiles(int JobAdsArrayLen, ClassAd* JobAdsArray[], CondorError
 		if (!JobAdsArray[i]->LookupInteger(ATTR_CLUSTER_ID,jobid.cluster)) {
 			dprintf(D_ALWAYS,"DCSchedd:spoolJobFiles: "
 					"Job ad %d did not have a cluster id\n",i);
+			if ( errstack ) {
+				errstack->pushf( "DCSchedd::spoolJobFiles", 1,
+								 "Job ad %d did not have a cluster id", i );
+			}
 			return false;
 		}
 		if (!JobAdsArray[i]->LookupInteger(ATTR_PROC_ID,jobid.proc)) {
 			dprintf(D_ALWAYS,"DCSchedd:spoolJobFiles: "
 					"Job ad %d did not have a proc id\n",i);
+			if ( errstack ) {
+				errstack->pushf( "DCSchedd::spoolJobFiles", 1,
+								 "Job ad %d did not have a proc id", i );
+			}
 			return false;
 		}
 		rsock.code(jobid);
@@ -1070,6 +1161,10 @@ DCSchedd::updateGSIcredential(const int cluster, const int proc,
 		// check the parameters
 	if ( cluster < 1 || proc < 0 || !path_to_proxy_file || !errstack ) {
 		dprintf(D_FULLDEBUG,"DCSchedd::updateGSIcredential: bad parameters\n");
+		if ( errstack ) {
+			errstack->push( "DCSchedd::updateGSIcredential", 1,
+							"bad parameters" );
+		}
 		return false;
 	}
 
@@ -1078,6 +1173,11 @@ DCSchedd::updateGSIcredential(const int cluster, const int proc,
 	if( ! rsock.connect(_addr) ) {
 		dprintf( D_ALWAYS, "DCSchedd::updateGSIcredential: "
 				 "Failed to connect to schedd (%s)\n", _addr );
+		if ( errstack ) {
+			errstack->push( "DCSchedd::updateGSIcredential",
+							CEDAR_ERR_CONNECT_FAILED,
+							"Failed to connect to schedd" );
+		}
 		return false;
 	}
 	if( ! startCommand(UPDATE_GSI_CRED, (Sock*)&rsock, 0, errstack) ) {
@@ -1103,7 +1203,12 @@ DCSchedd::updateGSIcredential(const int cluster, const int proc,
 	jobid.proc = proc;	
 	if ( !rsock.code(jobid) || !rsock.end_of_message() ) {
 		dprintf(D_ALWAYS,"DCSchedd:updateGSIcredential: "
-				"Can't send jobid to the schedd\n");
+				"Can't send jobid to the schedd, probably an authorization failure\n");
+		if ( errstack ) {
+			errstack->push( "DCSchedd::updateGSIcredential",
+							CEDAR_ERR_PUT_FAILED,
+							"Can't send jobid to the schedd, probably an authorization failure" );
+		}
 		return false;
 	}
 
@@ -1114,6 +1219,11 @@ DCSchedd::updateGSIcredential(const int cluster, const int proc,
 			"DCSchedd:updateGSIcredential "
 			"failed to send proxy file %s (size=%ld)\n",
 			path_to_proxy_file, (long) file_size);
+		if ( errstack ) {
+			errstack->push( "DCSchedd::updateGSIcredential",
+							CEDAR_ERR_PUT_FAILED,
+							"Failed to send proxy file" );
+		}
 		return false;
 	}
 		
@@ -1142,6 +1252,10 @@ DCSchedd::delegateGSIcredential(const int cluster, const int proc,
 		// check the parameters
 	if ( cluster < 1 || proc < 0 || !path_to_proxy_file || !errstack ) {
 		dprintf(D_FULLDEBUG,"DCSchedd::delegateGSIcredential: bad parameters\n");
+		if ( errstack ) {
+			errstack->push( "DCSchedd::delegateGSIcredential", 1,
+							"bad parameters" );
+		}
 		return false;
 	}
 
@@ -1150,6 +1264,11 @@ DCSchedd::delegateGSIcredential(const int cluster, const int proc,
 	if( ! rsock.connect(_addr) ) {
 		dprintf( D_ALWAYS, "DCSchedd::delegateGSIcredential: "
 				 "Failed to connect to schedd (%s)\n", _addr );
+		if ( errstack ) {
+			errstack->push( "DCSchedd::delegateGSIcredential",
+							CEDAR_ERR_CONNECT_FAILED,
+							"Failed to connect to schedd" );
+		}
 		return false;
 	}
 	if( ! startCommand(DELEGATE_GSI_CRED_SCHEDD, (Sock*)&rsock, 0, errstack) ) {
@@ -1175,7 +1294,12 @@ DCSchedd::delegateGSIcredential(const int cluster, const int proc,
 	jobid.proc = proc;	
 	if ( !rsock.code(jobid) || !rsock.end_of_message() ) {
 		dprintf(D_ALWAYS,"DCSchedd::delegateGSIcredential: "
-				"Can't send jobid to the schedd\n");
+				"Can't send jobid to the schedd, probably an authorization failure\n");
+		if ( errstack ) {
+			errstack->push( "DCSchedd::delegateGSIcredential",
+							CEDAR_ERR_PUT_FAILED,
+							"Can't send jobid to the schedd, probably an authorization failure" );
+		}
 		return false;
 	}
 
@@ -1186,6 +1310,11 @@ DCSchedd::delegateGSIcredential(const int cluster, const int proc,
 			"DCSchedd::delegateGSIcredential "
 			"failed to send proxy file %s\n",
 			path_to_proxy_file);
+		if ( errstack ) {
+			errstack->push( "DCSchedd::delegateGSIcredential",
+							CEDAR_ERR_PUT_FAILED,
+							"Failed to send proxy file" );
+		}
 		return false;
 	}
 		
@@ -1248,6 +1377,10 @@ DCSchedd::actOnJobs( JobAction action,
 					 "Can't insert constraint (%s) into ClassAd!\n",
 					 constraint );
 			free( tmp );
+			if ( errstack ) {
+				errstack->push( "DCSchedd::actOnJobs", 1,
+								"Can't insert constraint into ClassAd" );
+			}
 			return NULL;
 		}			
 		free( tmp );
@@ -1295,6 +1428,10 @@ DCSchedd::actOnJobs( JobAction action,
 	if( ! rsock.connect(_addr) ) {
 		dprintf( D_ALWAYS, "DCSchedd::actOnJobs: "
 				 "Failed to connect to schedd (%s)\n", _addr );
+		if ( errstack ) {
+			errstack->push( "DCSchedd::actOnJobs", CEDAR_ERR_CONNECT_FAILED,
+							"Failed to connect to schedd" );
+		}
 		return NULL;
 	}
 	if( ! startCommand(ACT_ON_JOBS, (Sock*)&rsock, 0, errstack) ) {
@@ -1311,7 +1448,11 @@ DCSchedd::actOnJobs( JobAction action,
 
 		// Now, put the command classad on the wire
 	if( ! (putClassAd(&rsock, cmd_ad) && rsock.end_of_message()) ) {
-		dprintf( D_ALWAYS, "DCSchedd:actOnJobs: Can't send classad\n" );
+		dprintf( D_ALWAYS, "DCSchedd:actOnJobs: Can't send classad, probably an authorization failure\n" );
+		if ( errstack ) {
+			errstack->push( "DCSchedd::actOnJobs", CEDAR_ERR_PUT_FAILED,
+							"Can't send classad, probably an authorization failure" );
+		}
 		return NULL;
 	}
 
@@ -1324,6 +1465,10 @@ DCSchedd::actOnJobs( JobAction action,
 	if( ! (getClassAd(&rsock, *result_ad) && rsock.end_of_message()) ) {
 		dprintf( D_ALWAYS, "DCSchedd:actOnJobs: "
 				 "Can't read response ad from %s\n", _addr );
+		if ( errstack ) {
+			errstack->push( "DCSchedd::actOnJobs", CEDAR_ERR_GET_FAILED,
+							"Can't read response ad" );
+		}
 		delete( result_ad );
 		return NULL;
 	}
@@ -1345,6 +1490,10 @@ DCSchedd::actOnJobs( JobAction action,
 	int answer = OK;
 	if( ! (rsock.code(answer) && rsock.end_of_message()) ) {
 		dprintf( D_ALWAYS, "DCSchedd:actOnJobs: Can't send reply\n" );
+		if ( errstack ) {
+			errstack->push( "DCSchedd::actOnJobs", CEDAR_ERR_PUT_FAILED,
+							"Can't send reply" );
+		}
 		delete( result_ad );
 		return NULL;
 	}
@@ -1355,6 +1504,10 @@ DCSchedd::actOnJobs( JobAction action,
 	if( ! (rsock.code(reply) && rsock.end_of_message()) ) {
 		dprintf( D_ALWAYS, "DCSchedd:actOnJobs: "
 				 "Can't read confirmation from %s\n", _addr );
+		if ( errstack ) {
+			errstack->push( "DCSchedd::actOnJobs", CEDAR_ERR_GET_FAILED,
+							"Can't read confirmation" );
+		}
 		delete( result_ad );
 		return NULL;
 	}
