@@ -37,6 +37,7 @@ private:
 	enum CommandProtocolState {
 		CommandProtocolAcceptTCPRequest,
 		CommandProtocolAcceptUDPRequest,
+		CommandProtocolReadHeader,
 		CommandProtocolReadCommand,
 		CommandProtocolAuthenticate,
 		CommandProtocolPostAuthenticate,
@@ -69,12 +70,13 @@ private:
 	ClassAd m_auth_info;
 	KeyInfo *m_key;
 	char    *m_sid;
+	void *m_prev_sock_ent;
 
 	UtcTime m_handle_req_start_time;
 	UtcTime m_async_waiting_start_time;
 	float m_async_waiting_time;
 	SecMan *m_sec_man;
-	DaemonCore::CommandEnt *m_comTable;
+	ExtArray<DaemonCore::CommandEnt> &m_comTable;
 	const static std::string WaitForSocketDataString;
 	int m_real_cmd;       // for DC_AUTHENTICATE, the final command to execute
 	int m_auth_cmd;       // for DC_AUTHENTICATE, the command the security session will be used for
@@ -85,6 +87,7 @@ private:
 
 	CommandProtocolResult AcceptTCPRequest();
 	CommandProtocolResult AcceptUDPRequest();
+	CommandProtocolResult ReadHeader();
 	CommandProtocolResult ReadCommand();
 	CommandProtocolResult Authenticate();
 	CommandProtocolResult PostAuthenticate();
