@@ -1538,7 +1538,7 @@ handle_config( Service *, int cmd, Stream *stream )
 		to_check = strdup(admin);
 	}
 	if (!is_valid_param_name(to_check + is_meta)) {
-		dprintf( D_ALWAYS, "Rejecting attempt to set param with invalid name (%s)\n", to_check);
+		dprintf( D_ALWAYS, "Rejecting attempt to set param with invalid name (%s)\n", (to_check?to_check:"(null)") );
 		free(admin); free(config);
 		rval = -1;
 		failed = true;
