@@ -26,6 +26,7 @@
 #include "read_multiple_logs.h"
 #include "throttle_by_category.h"
 #include "dag.h"
+#include "dagman_metrics.h"
 #include <set>
 
 static const char *JOB_TAG_NAME = "+job_tag_name";
@@ -463,9 +464,7 @@ Job::CanAddChild( Job* child, MyString &whynot )
 bool
 Job::TerminateSuccess()
 {
-	std::vector<unsigned char> s;
-	_onHold.swap(s); // Free memory in _onHold
-
+	Cleanup();
 	SetStatus( STATUS_DONE );
 	return true;
 } 
@@ -473,8 +472,7 @@ Job::TerminateSuccess()
 bool
 Job::TerminateFailure()
 {
-	std::vector<unsigned char> s;
-	s.swap(_onHold); // Free memory in _onHold;
+	Cleanup();
 	SetStatus( STATUS_ERROR );
 	return true;
 } 
@@ -878,7 +876,7 @@ Job::MonitorLogFile( ReadMultipleUserLogs &condorLogReader,
 					GetJobName() );
 		debug_printf( DEBUG_QUIET, "%s\n", errstack.getFullText().c_str() );
 		LogMonitorFailed();
-		EXCEPT( "Fatal log file monitoring error!\n" );
+		EXCEPT( "Fatal log file monitoring error!" );
 		return false;
 	}
 
@@ -914,7 +912,7 @@ Job::UnmonitorLogFile( ReadMultipleUserLogs &condorLogReader,
 					"ERROR: Unable to unmonitor log " "file for node %s",
 					GetJobName() );
 		debug_printf( DEBUG_QUIET, "%s\n", errstack.getFullText().c_str() );
-		EXCEPT( "Fatal log file monitoring error!\n" );
+		EXCEPT( "Fatal log file monitoring error!" );
 	}
 
 	if ( result ) {
@@ -1079,3 +1077,67 @@ bool Job::Release(int proc)
 	}
 	return false;
 }
+
+//---------------------------------------------------------------------------
+void
+Job::ExecMetrics( int proc, const struct tm &eventTime,
+			DagmanMetrics *metrics )
+{
+	if ( proc >= static_cast<int>( _gotEvents.size() ) ) {
+		_gotEvents.resize( proc+1, 0 );
+	}
+
+	if ( _gotEvents[proc] & ABORT_TERM_MASK ) {
+		debug_printf( DEBUG_NORMAL,
+					"Warning for node %s: got execute event for proc %d, but already have terminated or aborted event!\n",
+					GetJobName(), proc );
+		check_warning_strictness( DAG_STRICT_2 );
+	}
+
+	if ( !( _gotEvents[proc] & EXEC_MASK ) ) {
+		_gotEvents[proc] |= EXEC_MASK;
+		metrics->ProcStarted( eventTime );
+	}
+}
+
+//---------------------------------------------------------------------------
+void
+Job::TermAbortMetrics( int proc, const struct tm &eventTime,
+			DagmanMetrics *metrics )
+{
+	if ( proc >= static_cast<int>( _gotEvents.size() ) ) {
+		debug_printf( DEBUG_NORMAL,
+					"Warning for node %s: got terminated or aborted event for proc %d, but no execute event!\n",
+					GetJobName(), proc );
+		check_warning_strictness( DAG_STRICT_2 );
+
+		_gotEvents.resize( proc+1, 0 );
+	}
+
+	if ( !( _gotEvents[proc] & ABORT_TERM_MASK ) ) {
+		_gotEvents[proc] |= ABORT_TERM_MASK;
+		metrics->ProcFinished( eventTime );
+	}
+}
+
+//---------------------------------------------------------------------------
+void
+Job::Cleanup()
+{
+	std::vector<unsigned char> s;
+	_onHold.swap(s); // Free memory in _onHold
+
+	for ( int proc = 0; proc < static_cast<int>( _gotEvents.size() );
+				proc++ ) {
+		if ( _gotEvents[proc] != ( EXEC_MASK | ABORT_TERM_MASK ) ) {
+			debug_printf( DEBUG_NORMAL,
+					"Warning for node %s: unexpected _gotEvents value for proc %d: %d!\n",
+					GetJobName(), proc, (int)_gotEvents[proc] );
+			check_warning_strictness( DAG_STRICT_2 );
+		}
+	}
+
+	std::vector<unsigned char> s2;
+	_gotEvents.swap(s2); // Free memory in _gotEvents
+
+}
