@@ -23,6 +23,11 @@
 
 #include "MyString.h"
 
+enum condor_protocol { CP_INVALID_MIN, CP_IPV4, CP_IPV6, CP_INVALID_MAX };
+// Return a human friendly(ish) name for a protocol. Suitable for
+// use in log messages.
+MyString condor_protocol_to_str(condor_protocol p);
+
 class condor_sockaddr 
 {
 	union {
@@ -70,6 +75,7 @@ public:
 	bool is_link_local() const;
 
 	// set ip version when you want to bind the address to a socket
+	void set_protocol(condor_protocol proto);
 	void set_ipv4();
 	void set_ipv6();
 
