@@ -75,7 +75,7 @@ Condor_Auth_X509 :: Condor_Auth_X509(ReliSock * sock)
 		if (param(gsi_authz_conf, "GSI_AUTHZ_CONF")) {
 			if (setenv("GSI_AUTHZ_CONF", gsi_authz_conf.c_str(), 1)) {
 				dprintf(D_ALWAYS, "Failed to set the GSI_AUTHZ_CONF environment variable.\n");
-				EXCEPT("Failed to set the GSI_AUTHZ_CONF environment variable.\n");
+				EXCEPT("Failed to set the GSI_AUTHZ_CONF environment variable.");
 			}
 		}
 		// In 99% of cases, this is a no-op because the Globus threading model defaults
