@@ -108,7 +108,7 @@ LeaseManagerIntervalTimer::Config( void )
 			m_TimerId = daemonCore->Register_Timer(
 				m_Initial, m_Interval, m_Handler, handler_name, m_LeaseManager );
 			if ( m_TimerId < 0 ) {
-				EXCEPT( "LeaseManager: Failed to %s create timer\n", m_Name );
+				EXCEPT( "LeaseManager: Failed to %s create timer", m_Name );
 			}
 		} else {
 			daemonCore->Reset_Timer( m_TimerId, m_Interval, m_Interval );
