@@ -1,9 +1,14 @@
 #! /usr/bin/env perl
 use strict;
 use warnings;
+use Cwd;
 use IPC::Open3;
 use Time::HiRes qw(tv_interval gettimeofday);
 use Archive::Tar;
+use IO::Socket;
+use IO::Socket::INET;
+use IO::Handle;
+use Socket;
 
 BEGIN {
 	if ($^O =~ /MSWin32/) {
@@ -14,11 +19,16 @@ BEGIN {
 
 package CondorUtils;
 
+#if(CondorUtils::is_windows()) {
+	#use Win32::Pipe;
+#}
+
 our $VERSION = '1.00';
+my $btdebug = 0;
 
 use base 'Exporter';
 
-our @EXPORT = qw(runcmd FAIL PASS ANY SIGNALED SIGNAL async_read verbose_system Which TRUE FALSE is_cygwin_perl is_windows is_windows_native_perl fullchomp CreateDir CopyIt TarCreate TarExtract MoveIt DirLs List);
+our @EXPORT = qw(runcmd FAIL PASS ANY SIGNALED SIGNAL async_read verbose_system Which TRUE FALSE is_cygwin_perl is_windows is_windows_native_perl is_cygwin_perl fullchomp CreateEmptyFile CreateDir CopyIt TarCreate TarExtract MoveIt GetDirList DirLs List WhereIsInstallDir quoteMyString MyHead GeneralServer GeneralClient DagmanReadFlowLog);
 
 sub TRUE{1};
 sub FALSE{0};
@@ -351,6 +361,16 @@ sub runcmd {
 	#print "expected returnval was <$expected>\n";
 	$returnthings{"expectation"} = $expected;
 	if(!$expected && (${$options}{die_on_failed_expectation} == TRUE)) {
+		print "****** STDOUT ******\n";
+		foreach my $thing1 (@outlines) {
+			print "$thing1\n";
+		}
+		print "****** STDOUT ******\n";
+		print "****** STDERR ******\n";
+		foreach my $thing2 (@errlines) {
+			print "$thing2\n";
+		}
+		print "****** STDERR ******\n";
 		die "Expectation Failed on cmd <$args>\n";
 	} else {
 		#print "runcmd: Told Failure was OK\n";
@@ -509,13 +529,35 @@ sub Which {
 
     return "" if(!$exe);
 
+#print "Which: looking for: $exe\n";
     if( is_windows_native_perl() ) {
+		if($btdebug == 1) {
+			print "windows native perl!\n";
+		}
         return `\@for \%I in ($exe) do \@echo(\%~\$PATH:I`;
     }
-    foreach my $path (split /:/, $ENV{PATH}) {
-        chomp $path;
+	my $amwindows = is_windows();
+
+	my @winpath = {};
+	if($amwindows == 1) {
+		if(is_cygwin_perl()) {
+			@winpath = split /:/, $ENV{PATH};
+			#$exe = "$exe" . ".exe";
+		} else {
+			@winpath = split /;/, $ENV{PATH};
+			# should not get here
+		}
+	} else {
+		@winpath = split /:/, $ENV{PATH};
+	}
+
+    foreach my $path (@winpath) {
+        fullchomp( $path);
 		#print "Checking <$path>\n";
         if(-f "$path/$exe") {
+			if($btdebug == 1) {
+				print "Which returning:$path/$exe\n";
+			}
             return "$path/$exe";
         }
     }
@@ -557,6 +599,35 @@ sub is_windows_native_perl {
     return 0;
 }
 
+sub quoteMyString {
+	my $stringtoquote = shift;
+	my $returnstr = "";
+	print "Quote:$stringtoquote\n";
+	if(is_windows()) {
+		$_ = $stringtoquote;
+		s/%/\%/g;
+		s/"/\"/g;
+		if($stringtoquote =~ /\s+/) {
+			$returnstr = "\"" . $_ . "\"";
+		} else {
+			$returnstr = $_;
+		}
+	} else {
+		$_ = $stringtoquote;
+		s/'/\'/g;
+		$returnstr = "'$_'";
+	}
+	print "Returning:$returnstr\n";
+	return($returnstr);
+}
+
+sub CreateEmptyFile {
+	my $name = shift;
+	open(NF,">$name") or die "Failed to create:$name:$!\n";
+	print NF "";
+	close(NF);
+}
+
 sub CreateDir
 {
 	my $cmdline = shift;
@@ -564,41 +635,73 @@ sub CreateDir
 	my $cmdcount = @argsin;
 	my $ret = 0;
 	my $fullcmd = "";
-	#print  "CreateDir: $cmdline argcout:$cmdcount\n";
+	my $location = Cwd::getcwd();
+	#print  "\n\n\n\n\n******* CreateDir: $cmdline argcout:$cmdcount while here:$location *******\n\n\n\n\n";
 
 	my $amwindows = is_windows();
 
 	my $winpath = "";
 	if($amwindows == 1) {
-		if($argsin[0] eq "-p") {
-			$winpath = `cygpath -w $argsin[1]`;
-			CondorUtils::fullchomp($winpath);
-			$_ = $winpath;
-			s/\\/\\\\/g;
-			$winpath = $_;
-			if(-d "$argsin[1]") {
-				return($ret);
+		if(is_windows_native_perl()) {
+			#print "CreateDir:windows_native_perl\n";
+			# what if a linux path first?
+			if($argsin[0] eq "-p") {
+				shift @argsin;
 			}
+			foreach my $dir (@argsin) {
+				#print "Want to make:$dir\n";
+				$_ = $dir;
+				s/\//\\/g;
+				s/\\/\\\\/g;
+				$dir = $_;
+				if(-d "$dir") {
+					next;
+				}
+				#print "$dir does not exist yet\n";
+				$fullcmd = "cmd /C mkdir $dir";
+				$ret = system("$fullcmd");
+				if($ret != 0) {
+					print "THIS:$fullcmd Failed\n";
+				} else {
+						#print "THIS:$fullcmd worked\n";
+						#print "If this worked, it should exist now.\n";
+						#if(-d $dir) {
+							#print "Perl says it does.\n";
+						#} else {
+							#print "Perl says it does NOT.\n";
+						#}
+				}
+			}
+			#print "CreateDir returning now: Return value from CreateDir:$ret\n";
+			return($ret);
 		} else {
-			$winpath = `cygpath -w $argsin[0]`;
-			CondorUtils::fullchomp($winpath);
-			$_ = $winpath;
-			s/\\/\\\\/g;
-			$winpath = $_;
-			if(-d "$argsin[0]") {
-				return($ret);
+			if($argsin[0] eq "-p") {
+				$winpath = `cygpath -w $argsin[1]`;
+				CondorUtils::fullchomp($winpath);
+				$_ = $winpath;
+				s/\\/\\\\/g;
+				$winpath = $_;
+				if(-d "$argsin[1]") {
+					return($ret);
+				}
+			} else {
+				$winpath = `cygpath -w $argsin[0]`;
+				CondorUtils::fullchomp($winpath);
+				$_ = $winpath;
+				s/\\/\\\\/g;
+				$winpath = $_;
+				if(-d "$argsin[0]") {
+					return($ret);
+				}
 			}
 		}
 
 		$fullcmd = "cmd /C mkdir $winpath";
 		$ret = system("$fullcmd");
-		#print "Tried to create dir got ret value:$ret path:$winpath/$fullcmd\n";
-	} else {
-		if($cmdline =~ /\-p/) {
-			$_ = $cmdline;
-			s/\-p//;
-			$cmdline = $_;
+		if($btdebug == 1) {
+			print "Tried to create dir got ret value:$ret path:$winpath:$fullcmd\n";
 		}
+	} else {
 		$fullcmd = "mkdir $cmdline"; 	
 		if(-d $cmdline) {
 			return($ret);
@@ -609,39 +712,59 @@ sub CreateDir
 	return($ret);
 }
 
+# pretty print a time string, if no args are passed uses localtime() as the time.
+# the output is formatted as YYYY-MM-DD HH:MM:SS (which is sortable)
+# if the last argument is 'T', then only the time is printed.
+sub TimeStr
+{
+	my $ac = scalar(@_);
+	my $T = $ac > 0 && $_[$ac-1] eq 'T';
+	if ($ac < 5) { @_ = localtime(); }
+	if ($T) { return sprintf "%02d:%02d:%02d", @_[reverse 0..3]; }
+	return sprintf '%d-%02d-%02d %02d:%02d:%02d', $_[5]+1900, $_[4]+1, @_[reverse 0..3];
+}
+
+# portable way to get a directory listing
+# the command ls is optional, (sigh) because that's the way it's used...
 sub List
 {
     my $cmdline = shift;
-	my @allargs = split /\s/, $cmdline;
-    my $amwindows = is_windows();
-    my $fullcmd = "";
 	my $ret = 0;
+	# strip off leading ls command (it's ok if its not there)
+	if ($cmdline =~ /^\s*ls\s+/) { $cmdline =~ s/^\s*ls\s+//; }
 
-    if($amwindows == 1) {
-		$fullcmd = "cmd /C dir ";
-
-		foreach my $patharg (@allargs) {
-			if($patharg =~ /cygdrive/) {
-				my $winpath = `cygpath -w $patharg`;
-        		CondorUtils::fullchomp($winpath);
-				$_ = $winpath;
-        		s/\\/\\\\/g;
-				$winpath = $_;
-				$fullcmd = $fullcmd . " $winpath";
-			} else {
-				$fullcmd = $fullcmd . " $patharg";
-	}
+	# on native windows, we are translating ls to dir, so we also need to strip the options
+	if (is_windows_native_perl()) {
+		if ($cmdline =~ /^\-([a-zA-Z]+)\s+(.*)$/ ) {
+			# translate flags?
+			#my $flags = $1;
+			$cmdline = $2;;
 		}
-
-		$ret = system("$fullcmd");
-	} else {
-		$fullcmd = "ls $cmdline";
-
-		$ret = system("$fullcmd");
+		$ret = system("cmd /C dir $cmdline");
+	} elsif (is_windows()) {
+		$cmdline =~ s/\\/\//g; # if windows, but not native, we need to convert \ to / before passing to ls.
+	}
+	else {
+		$ret = system("ls $cmdline");
 	}
 	return($ret);
 }
 
+sub GetDirList {
+	my $arrayref = shift;
+	my $targetdir = shift;
+	my $startdir = Cwd::getcwd();
+	chdir("$targetdir");
+	opendir DS, "." or die "Can not open dataset: $1\n";
+	foreach my $subfile (readdir DS)
+	{
+		next if $subfile =~ /^\.\.?$/;
+		push  @{$arrayref}, $subfile;
+	}
+	close(DS);
+	chdir("$startdir");
+}
+
 sub DirLs
 {
     my $cmdline = shift;
@@ -661,6 +784,30 @@ sub DirLs
 	return($ret);
 }
 
+
+sub dir_listing {
+	my (@path) = @_;
+
+	my $path = File::Spec->catdir(@path);
+
+	# If we have a relative path then show the CWD
+	my $cwd = "";
+	if(not File::Spec->file_name_is_absolute($path)) {
+		$cwd = "(CWD: '" . Cwd::getcwd() . "')";
+	}
+	if($btdebug == 1) {
+		print "Showing directory contents of path '$path' $cwd\n";
+	}
+    
+	# We have to check $^O because the platform_* scripts will be executed on a Linux
+	# submit node - but the nmi platform string will have winnt
+	if( is_windows() && $^O ne "linux" ) {
+		system("dir $path");
+	} else {
+		system("ls -l $path");
+	}
+}
+
 sub CopyIt
 {
     my $cmdline = shift;
@@ -682,24 +829,44 @@ sub CopyIt
     my @argsin = split /\s/, $cmdline;
     my $cmdcount = @argsin;
 
+	if($btdebug == 1) {
+		print "CopyIt command line passed in:$cmdline\n";
+	}
     if($amwindows == 1) {
-        $winsrc = `cygpath -w $argsin[0]`;
-        $windest = `cygpath -w $argsin[1]`;
-        CondorUtils::fullchomp($winsrc);
-        CondorUtils::fullchomp($windest);
-        $_ = $winsrc;
-        s/\\/\\\\/g;
-        $winsrc = $_;
-        $_ = $windest;
-        s/\\/\\\\/g;
-        $windest = $_;
-        $fullcmd = "xcopy $winsrc $windest /Y";
-        if($dashr eq "yes") {
-            $fullcmd = $fullcmd . " /s /e";
-        }
+		if(is_windows_native_perl()) {
+			#print "CopyIt: windows_native_perl\n";
+			$winsrc = $argsin[0];
+			$windest = $argsin[1];
+			#print "native perl:\n";
+			# check target
+			$windest =~ s/\//\\/g;
+        	$fullcmd = "xcopy $winsrc $windest /Y";
+			#print "native perl:$fullcmd\n";
+        	if($dashr eq "yes") {
+            	$fullcmd = $fullcmd . " /s /e";
+				#print "native perl -r:$fullcmd\n";
+        	}
+		} else {
+        	$winsrc = `cygpath -w $argsin[0]`;
+        	$windest = `cygpath -w $argsin[1]`;
+        	CondorUtils::fullchomp($winsrc);
+        	CondorUtils::fullchomp($windest);
+        	$_ = $winsrc;
+        	s/\\/\\\\/g;
+        	$winsrc = $_;
+        	$_ = $windest;
+        	s/\\/\\\\/g;
+        	$windest = $_;
+        	$fullcmd = "xcopy $winsrc $windest /Y";
+        	if($dashr eq "yes") {
+            	$fullcmd = $fullcmd . " /s /e";
+        	}
 
+		}
         $ret = system("$fullcmd");
-		#print "Tried to create dir got ret value:$ret cmd:$fullcmd\n";
+		if($btdebug == 1) {
+			print "Tried to create dir got ret value:$ret cmd:$fullcmd\n";
+		}
     } else {
         $fullcmd = "cp ";
         if($dashr eq "yes") {
@@ -709,6 +876,10 @@ sub CopyIt
         $ret = system("$fullcmd");
 		#print "Tried to create dir got ret value:$ret path:$cmdline\n";
     }
+	if($btdebug == 1) {
+		print "CopyIt returning:$ret\n";
+	}
+	
     return($ret);
 }
 
@@ -729,16 +900,24 @@ sub MoveIt
 	my $cmdcount = @argsin;
 
 	if($amwindows == 1) {
-		$winsrc = `cygpath -w $argsin[0]`;
-		$windest = `cygpath -w $argsin[1]`;
-		CondorUtils::fullchomp($winsrc);
-		CondorUtils::fullchomp($windest);
-		$_ = $winsrc;
-		s/\\/\\\\/g;
-		$winsrc = $_;
-		$_ = $windest;
-		s/\\/\\\\/g;
-		$windest = $_;
+		if(is_windows_native_perl()) {
+			#print "MoveIt:windows_native_perl\n";
+			$winsrc =  $argsin[0];
+			$windest = $argsin[1];
+			$winsrc =~ s/\//\\/g;
+			$windest =~ s/\//\\/g;
+		} else {
+			$winsrc = `cygpath -w $argsin[0]`;
+			$windest = `cygpath -w $argsin[1]`;
+			CondorUtils::fullchomp($winsrc);
+			CondorUtils::fullchomp($windest);
+			$_ = $winsrc;
+			s/\\/\\\\/g;
+			$winsrc = $_;
+			$_ = $windest;
+			s/\\/\\\\/g;
+			$windest = $_;
+		}
 		$fullcmd = "cmd /C move $winsrc $windest";
 
 		$ret = system("$fullcmd");
@@ -763,12 +942,318 @@ sub TarExtract
 	my $winpath = "";
 	my $tarobject = Archive::Tar->new;
 	if($amwindows == 1) {
-		$winpath = `cygpath -w $archive`;
-		CondorUtils::fullchomp($winpath);
-		$archive = $winpath;
+		if( is_windows_native_perl() ) {
+        } else {
+            $winpath = `cygpath -w $archive`;
+            CondorUtils::fullchomp($winpath);
+            $archive = $winpath;
+        }
 	}
 	$tarobject->read($archive);
 	$tarobject->extract();
 }
 
+sub WhereIsInstallDir {
+	my $base_dir = shift;
+	my $iswindows = shift;
+	my $iscygwin = shift;
+	my $iswindowsnativeperl = shift;
+
+	my $installdir = "";
+	my $wininstalldir = "";
+
+	my $top = $base_dir;
+	if($iswindows == 1) {
+		my $top = Cwd::getcwd();
+		if($btdebug == 1) {
+			print "base_dir is \"$top\"\n";
+		}
+		if ($iscygwin) {
+			my $crunched = `cygpath -m $top`;
+			fullchomp($crunched);
+			if($btdebug == 1) {
+				print "cygpath changed it to: \"$crunched\"\n";
+			}
+			my $ppwwdd = `pwd`;
+			if($btdebug == 1) {
+				print "pwd says: $ppwwdd\n";
+			}
+		} else {
+			my $ppwwdd = `cd`;
+			if($btdebug == 1) {
+				print"cd says: $ppwwdd\n";
+			}
+		}
+	}
+
+	my $master_name = "condor_master"; if ($iswindows) { $master_name = "condor_master.exe"; }
+	my $tmp = Which($master_name);
+	if ( ! ($tmp =~ /condor_master/ ) ) {
+		print STDERR "Which($master_name) returned:$tmp\n";
+		print STDERR "Unable to find a $master_name in your PATH!\n";
+		system("ls build");
+		print "PATH: $ENV{PATH}\n";
+		exit(1);
+	} else {
+		if($btdebug == 1) {
+			print "Found master via Which here:$tmp\n";
+		}
+	}
+	fullchomp($tmp);
+	if($btdebug == 1) {
+		print "Install Directory \"$tmp\"\n";
+	}
+	if ($iswindows) {
+		if ($iscygwin) {
+			$tmp =~ s|\\|/|g; # convert backslashes to forward slashes.
+			if($tmp =~ /^(.*)\/bin\/condor_master.exe\s*$/) {
+				$installdir = $1;
+				$tmp = `cygpath -m $1`;
+				fullchomp($tmp);
+				$wininstalldir = $tmp;
+			}
+		} else {
+			$tmp =~ s/\\bin\\condor_master.exe$//i;
+			$installdir = $tmp;
+			$wininstalldir = $tmp;
+		}
+		$wininstalldir =~ s|/|\\|g; # forward slashes.to backslashes
+		$installdir =~ s|\\|/|g; # convert backslashes to forward slashes.
+		if($btdebug == 1) {
+			print "Testing this Install Directory: \"$wininstalldir\"\n";
+		}
+	} else {
+		$wininstalldir = "none";
+		$tmp =~ s|//|/|g;
+		if( ($tmp =~ /^(.*)\/sbin\/condor_master\s*$/) || \
+				($tmp =~ /^(.*)\/bin\/condor_master\s*$/) ) {
+			$installdir = $1;
+			if($btdebug == 1) {
+				print "Testing This Install Directory: \"$installdir\"\n";
+			}
+		} else {
+			die "'$tmp' didn't match path RE\n";
+		}
+		if(defined $ENV{LD_LIBRARY_PATH}) {
+			$ENV{LD_LIBRARY_PATH} = "$installdir/lib:$ENV{LD_LIBRARY_PATH}";
+		} else {
+			$ENV{LD_LIBRARY_PATH} = "$installdir/lib";
+		}
+		if(defined $ENV{PYTHONPATH}) {
+			$ENV{PYTHONPATH} = "$installdir/lib/python:$ENV{PYTHONPATH}";
+		} else {
+			$ENV{PYTHONPATH} = "$installdir/lib/python";
+		}
+	}
+	my $paths = "$installdir" . ",$wininstalldir";
+	return($paths);
+}
+
+sub MyHead {
+	my $size = shift;
+	my $file = shift;
+
+	print "Request:head $size $file\n";
+
+	if($size =~ /\-/) {
+		$_ = $size;
+		s/\-//;
+		print "$_\n";
+		$size = $_;
+	}
+	my $counter = 0;
+	open(MH,"<$file") or die "Open of $file failed:$!\n";
+	while(<MH>) {
+		print "$_";
+		$counter += 1;
+		if($counter == $size) {
+			last;
+		}
+	}
+	close(MH);
+}
+
+sub GeneralServer {
+	my $SockAddr = shift;
+	my $LogFile = shift;
+	my $raw = shift;
+
+	print "general server log file is $LogFile\n";
+
+	#open(OLDOUT, ">&STDOUT");
+	#open(OLDERR, ">&STDERR");
+	open(STDOUT, ">$LogFile") or die "Could not open $LogFile: $!";
+	open(STDERR, ">&STDOUT");
+	select(STDERR); $| = 1;
+	select(STDOUT); $| = 1;
+
+#	if(is_windows()) {
+#		my $server = IO::Socket::INET->new(
+#			LocalPort => '0',
+#			Proto  => 'udp',
+#			) or die "ERROR in Socket Creation:$!\n";
+#		print "Server has a socket\n";
+
+#		#my $eport = $server->sockport();
+#		#print "I am listening on port:$eport\n";
+#		my $mysockaddr = getsockname($server);
+#		if(defined $mysockaddr) {
+#			print "getsockname return $mysockaddr\n";
+#		} else {
+#			print "getsockname return undefined\n";
+#		}
+#		my ($port, $myaddr) = Socket::sockaddr_in($mysockaddr);
+#		print "I am listening on port:$port\n";
+#		printf "Connect to %s [%s]\n",
+#			scalar gethostbyaddr($myaddr, Socket::AF_INET),
+#			inet_ntoa($myaddr);
+#		# set no options for now
+#		#$server->setsockopt(Socket::SOL_SOCKET, Socket::SO_RCVBUF, 65440);
+
+#		while ( 1 )
+#		{
+#			my $newmsg;
+#			$server->recv($newmsg,1024) || die "Recv: $!";
+#			#$server->recv($newmsg,$MAXLEN);
+#			if($newmsg eq "quit")
+#			{
+#				exit(0);
+#			}
+#			if(defined($raw)) {
+#				print "$newmsg";
+#			} else {
+#				print "$newmsg\n";
+#			}
+#		}
+
+#		my $server = new Win32::Pipe($SockAddr);
+#		if(!(defined $server)) {
+#			die "Pipe not created:$SockAddr:$!\n";
+#		}
+
+#		while(1) {
+#			my $result = $server->Connect();
+#			if($result == 1) {
+#				my $newmsg = $server->Read();
+#				if($newmsg eq "quit")
+#				{
+#					exit(0);
+#				}
+#				if(defined($raw)) {
+#					print "$newmsg";
+#				} else {
+#					print "$newmsg\n";
+#				}
+#				my $disconnectres = $server->Disconnect();
+#				print "Disconnect res:$disconnectres:$!\n";
+#				# start with a single message
+#				 last;
+#			} else {
+#				print "Connect result:$result:$!\n";
+#			}
+#		}
+	#} else {
+		if(is_windows()) {
+		} else {
+			unlink($SockAddr);
+		}
+		print "About to NEW on $SockAddr\n";
+		my $server = IO::Socket::UNIX->new(Local => $SockAddr,
+									Type  => Socket::SOCK_DGRAM)
+		or die "Can't bind socket: $!\n";
+
+		$server->setsockopt(Socket::SOL_SOCKET, Socket::SO_RCVBUF, 65440);
+
+		while ( 1 )
+		{
+			my $newmsg;
+			my $MAXLEN = 1024;
+			#$server->recv($newmsg,$MAXLEN) || die "Recv: $!";
+			$server->recv($newmsg,$MAXLEN);
+			if($newmsg eq "quit")
+			{
+				exit(0);
+			}
+			if(defined($raw)) {
+				print "$newmsg";
+			} else {
+				print "$newmsg\n";
+			}
+		}
+
+		my $stat = 0;
+		my $returnval = shift;
+	#}
+	print "Server exiting\n";
+}
+
+sub GeneralClient {
+	my $MAXLEN = 1024;
+	my $comchan = shift;
+	my $newmsg = shift;
+
+	print "$comchan for mesg $newmsg\n";
+	
+	#if(is_windows()) {
+#		my $ClientSockAddr = "\\\\.\\pipe\\$comchan";
+#		my $pipe = new Win32::Pipe("$ClientSockAddr");
+#		if(!(defined $pipe)) {
+#			die "Client pipe creation and connection failed:$ClientSockAddr:$!\n";
+#		}
+#		my $result = $pipe->Write($newmsg);
+#		print "Pipe write result:$result:$!\n";
+#		$pipe->Close();
+	#} else {
+		my $client = IO::Socket::UNIX->new(Peer => "$comchan",
+								Type  => Socket::SOCK_DGRAM,
+								Timeout => 10)
+		or die $@;
+
+		$client->send($newmsg);
+
+		my $stat = 0;
+		my $returnval = shift;
+	#}
+	print "client exiting\n";
+}
+
+sub DagmanReadFlowLog {
+	my $log = shift;
+	my $option = shift; # $option not currently used
+	#my $limit = 2;
+	my $limit = shift;
+	my $count = 0;
+	my $line;
+
+	#print "Log is $log, Option is $option and limit is $limit\n";
+
+	open(OLDOUT, "<$log") or die "Failed to open:$log:$!\n";
+	while(<OLDOUT>)
+	{
+		CondorUtils::fullchomp($_);
+		$line = $_;
+		#print "--$line--\n";
+		if( $line =~ /^\s*(open)\s*$/ )
+		{
+			$count++;
+			#print "Count now $count\n";
+			if($count > $limit)
+			{
+				#print "$count exceeds $limit\n";
+				print "$count";
+				return($count);
+			}
+		}
+		if( $line =~ /^\s*(close)\s*$/ )
+		{
+			$count--;
+			#print "Count now $count\n";
+		}
+	}
+
+	close(OLDOUT);
+	print "$count";
+	return(0);
+}
+
 1;
