@@ -72,6 +72,7 @@ BaseShadow::BaseShadow() {
 	m_cleanup_retry_tid = -1;
 	m_cleanup_retry_delay = 30;
 	m_RunAsNobody = false;
+	m_force_fast_starter_shutdown = false;
 }
 
 BaseShadow::~BaseShadow() {
@@ -158,6 +159,9 @@ BaseShadow::baseInit( ClassAd *job_ad, const char* schedd_addr, const char *xfer
 
 	// handle system calls with Owner's privilege
 // XXX this belong here?  We'll see...
+	// Calling init_user_ids() while in user priv causes badness.
+	// Make sure we're in another priv state.
+	set_condor_priv();
 	if ( !init_user_ids(owner.Value(), domain.Value())) {
 		dprintf(D_ALWAYS, "init_user_ids() failed as user %s\n",owner.Value() );
 		// uids.C will EXCEPT when we set_user_priv() now
@@ -415,6 +419,7 @@ BaseShadow::holdJob( const char* reason, int hold_reason_code, int hold_reason_s
 void
 BaseShadow::holdJobAndExit( const char* reason, int hold_reason_code, int hold_reason_subcode )
 {
+	m_force_fast_starter_shutdown = true;
 	holdJob(reason,hold_reason_code,hold_reason_subcode);
 
 	// finally, exit and tell the schedd what to do
@@ -1532,6 +1537,9 @@ BaseShadow::handleUpdateJobAd( int sig )
 bool
 BaseShadow::jobWantsGracefulRemoval()
 {
+	if ( m_force_fast_starter_shutdown ) {
+		return false;
+	}
 	bool job_wants_graceful_removal = param_boolean("GRACEFULLY_REMOVE_JOBS", true);
 	bool job_request;
 	ClassAd *thejobAd = getJobAd();
