@@ -354,6 +354,9 @@ class BaseShadow : public Service
 		/** Connect to the job queue and update one integer attribute */
 	virtual bool updateJobAttr( const char *name, int value, bool log=false );
 
+		/** Watch a job attribute for future updates */
+	virtual void watchJobAttr( const std::string & );
+
 		/** Do whatever cleanup (like killing starter(s)) that's
 			required before the shadow can exit.
 		*/
@@ -478,6 +481,9 @@ class BaseShadow : public Service
 		/// How long to delay between attempts to retry job cleanup.
 	int m_cleanup_retry_delay;
 
+		// Insist on a fast shutdown of the starter?
+	bool m_force_fast_starter_shutdown;
+
 		// This makes this class un-copy-able:
 	BaseShadow( const BaseShadow& );
 	BaseShadow& operator = ( const BaseShadow& );
