@@ -29,19 +29,26 @@ handle the incoming connections.
 
 #include "condor_daemon_core.h"
 
+class JICShadow;
+
 class IOProxy : public Service {
 public:
 	IOProxy();
 	~IOProxy();
 
-	bool init( const char *config_file );
+	bool init( JICShadow * shadow, const char *config_file, bool want_io, bool want_updates, bool want_delayed );
 
 private:
 	int connect_callback( Stream * );
 
-	char *cookie;
 	ReliSock *server;
+	JICShadow *m_shadow;
+	char *cookie;
 	bool socket_registered;
+
+	bool m_want_io;
+	bool m_want_updates;
+	bool m_want_delayed;
 };
 
 #endif
