@@ -43,11 +43,13 @@
 #include "condor_mkstemp.h"
 #include "globus_utils.h"
 
+#include <algorithm>
 
 extern CStarter *Starter;
 ReliSock *syscall_sock = NULL;
 extern const char* JOB_AD_FILENAME;
 extern const char* MACHINE_AD_FILENAME;
+const char* CHIRP_CONFIG_FILENAME = ".chirp.config";
 
 // Filenames are case insensitive on Win32, but case sensitive on Unix
 #ifdef WIN32
@@ -58,7 +60,8 @@ extern const char* MACHINE_AD_FILENAME;
 #	define file_remove remove
 #endif
 
-JICShadow::JICShadow( const char* shadow_name ) : JobInfoCommunicator()
+JICShadow::JICShadow( const char* shadow_name ) : JobInfoCommunicator(),
+	m_wrote_chirp_config(false)
 {
 	if( ! shadow_name ) {
 		EXCEPT( "Trying to instantiate JICShadow with no shadow name!" );
@@ -372,17 +375,19 @@ JICShadow::Continue( void )
 
 bool JICShadow::allJobsDone( void )
 {
-	bool r1, r2 = false;
 	ClassAd update_ad;
 
-	r1 = JobInfoCommunicator::allJobsDone();
+	bool r1 = JobInfoCommunicator::allJobsDone();
 
+	// Tell shadow job is done, and moving to job state transfer output
 	if (!m_did_transfer) {
 		publishJobExitAd( &update_ad );
-		r2 = updateShadow( &update_ad, true );
+		// Note if updateShadow() fails, it will dprintf into the log.
+		updateShadow( &update_ad, true );
 	}
 
-	return r1 || r2;
+	// only report success if our parent class is also done
+	return r1;
 }
 
 
@@ -397,6 +402,12 @@ JICShadow::transferOutput( bool &transient_failure )
 		return true;
 	}
 
+	bool spool_on_evict = true, tmp_value;
+	if (job_ad->EvaluateAttrBool("SpoolOnEvict", tmp_value))
+	{
+		spool_on_evict = tmp_value;
+	}
+
 	dprintf(D_FULLDEBUG, "JICShadow::transferOutput(void): Transferring...\n");
 
 		// transfer output files back if requested job really
@@ -424,9 +435,13 @@ JICShadow::transferOutput( bool &transient_failure )
 		// ft list
 		filetrans->addFileToExeptionList(JOB_AD_FILENAME);
 		filetrans->addFileToExeptionList(MACHINE_AD_FILENAME);
+		if (m_wrote_chirp_config) {
+			filetrans->addFileToExeptionList(CHIRP_CONFIG_FILENAME);
+		}
 	
-			// true if job exited on its own
-		bool final_transfer = (requested_exit == false);	
+			// true if job exited on its own or if we are set to not spool
+			// on eviction.
+		bool final_transfer = !spool_on_evict || (requested_exit == false);	
 
 			// The shadow may block on disk I/O for long periods of
 			// time, so set a big timeout on the starter's side of the
@@ -746,7 +761,11 @@ JICShadow::notifyJobExit( int exit_status, int reason, UserProc*
 			if (job_universe != CONDOR_UNIVERSE_PARALLEL)
 			{
 				job_cleanup_disconnected = true;
-				return false;
+					// If we're doing a fast shutdown, ignore any failures
+					// in talking to the shadow.
+				if ( !fast_exit ) {
+					return false;
+				}
 			}
 		}
 	}
@@ -1417,7 +1436,7 @@ JICShadow::initWithFileTransfer()
 	line += " = \"";
 	line += job_iwd;
 	line+= '"';
-	job_ad->InsertOrUpdate( line.Value() );
+	job_ad->Insert( line.Value() );
 
 		// now that we've got the iwd we're using and all our
 		// transfer-related flags set, we can finally initialize the
@@ -1825,9 +1844,66 @@ JICShadow::setX509ProxyExpirationTimer()
 }
 
 
+bool
+JICShadow::recordDelayedUpdate( const std::string &name, const classad::ExprTree &expr )
+{
+	std::string prefix;
+	param(prefix, "CHIRP_DELAYED_UPDATE_PREFIX", "CHIRP*");
+	if (!prefix.size())
+	{
+		dprintf(D_ALWAYS, "Got an invalid prefix for updates: %s\n", name.c_str());
+	}
+	StringList sl(prefix.c_str());
+	if (sl.contains_anycase_withwildcard(name.c_str()))
+	{
+		std::vector<std::string>::const_iterator it = std::find(m_delayed_update_attrs.begin(),
+			m_delayed_update_attrs.end(), name);
+		if (it == m_delayed_update_attrs.end())
+		{
+			if (m_delayed_update_attrs.size() >= 50)
+			{
+				dprintf(D_ALWAYS, "Ignoring update for %s because 50 attributes have already been set.\n", name.c_str());
+				return false;
+			}
+			m_delayed_update_attrs.push_back(name);
+		}
+		// Note that the ClassAd takes ownership of the copy.
+		dprintf(D_FULLDEBUG, "Got a delayed update for attribute %s.\n", name.c_str());
+		classad::ExprTree *expr_copy = expr.Copy();
+		m_delayed_updates.Insert(name, expr_copy);
+		return true;
+	}
+	else
+	{
+		dprintf(D_ALWAYS, "Got an invalid prefix for updates: %s\n", name.c_str());
+		return false;
+	}
+}
+
+
+
+std::auto_ptr<classad::ExprTree>
+JICShadow::getDelayedUpdate( const std::string &name )
+{
+	std::auto_ptr<classad::ExprTree> expr;
+	classad::ExprTree *borrowed_expr = NULL;
+	ClassAd *ad = jobClassAd();
+	dprintf(D_FULLDEBUG, "Looking up delayed attribute named %s.\n", name.c_str());
+	if (!(borrowed_expr = m_delayed_updates.Lookup(name)) && (!ad || !(borrowed_expr = ad->Lookup(name))))
+	{
+		return expr;
+	}
+	expr.reset(borrowed_expr->Copy());
+	return expr;
+}
+
 bool
 JICShadow::publishUpdateAd( ClassAd* ad )
 {
+	// These are updates taken from Chirp
+	ad->Update(m_delayed_updates);
+	m_delayed_updates.Clear();
+
 	filesize_t execsz = 0;
 
 	// if we are using PrivSep, we need to use that mechanism to calculate
@@ -1872,7 +1948,14 @@ JICShadow::publishUpdateAd( ClassAd* ad )
 		// walk through all the UserProcs and have those publish, as
 		// well.  It returns true if there was anything published,
 		// false if not.
-	return Starter->publishUpdateAd( ad );
+	bool retval = Starter->publishUpdateAd( ad );
+
+	// These are updates taken from Chirp
+	// Note they should not go to the starter!
+	ad->Update(m_delayed_updates);
+	m_delayed_updates.Clear();
+
+	return retval;
 }
 
 
@@ -1892,7 +1975,7 @@ JICShadow::publishJobExitAd( ClassAd* ad )
 		Directory starter_dir( Starter->GetWorkingDir(), PRIV_USER );
 		execsz = starter_dir.GetDirectorySize();
 		sprintf( buf, "%s=%lu", ATTR_DISK_USAGE, (long unsigned)((execsz+1023)/1024) ); 
-		ad->InsertOrUpdate( buf );
+		ad->Insert( buf );
 
 	}
 	MyString spooled_files;
@@ -1922,8 +2005,10 @@ bool
 JICShadow::periodicJobUpdate( ClassAd* update_ad, bool insure_update )
 {
 	bool r1, r2;
-	r1 = JobInfoCommunicator::periodicJobUpdate(update_ad, insure_update);
-	r2 = updateShadow(update_ad, insure_update);
+	// call updateShadow first, because this may have the side effect of clearing
+	// the m_delayed_update_attrs and we want to make sure that the shadow gets to see them.
+	r1 = updateShadow(update_ad, insure_update);
+	r2 = JobInfoCommunicator::periodicJobUpdate(update_ad, insure_update);
 	return (r1 && r2);
 }
 
@@ -2129,32 +2214,81 @@ JICShadow::initShadowInfo( ClassAd* ad )
 bool
 JICShadow::initIOProxy( void )
 {
-	int want_io_proxy = 0;
+	bool want_io_proxy = false;
 	MyString io_proxy_config_file;
 
 		// the admin should have the final say over whether
 		// chirp is enabled
     bool enableIOProxy = true;
 	enableIOProxy = param_boolean("ENABLE_CHIRP", true);
-	
-	if (!enableIOProxy) {
+
+	bool enableUpdates = false;
+	enableUpdates = param_boolean("ENABLE_CHIRP_UPDATES", true);
+
+	bool enableFiles = false;
+	enableFiles = param_boolean("ENABLE_CHIRP_IO", true);
+
+	bool enableDelayed = false;
+	enableDelayed = param_boolean("ENABLE_CHIRP_DELAYED", true);
+
+	if (!enableIOProxy || (!enableUpdates && !enableFiles && !enableDelayed)) {
 		dprintf(D_ALWAYS, "ENABLE_CHIRP is false in config file, not enabling chirp\n");
 		return false;
 	}
 
-	if( job_ad->LookupBool( ATTR_WANT_IO_PROXY, want_io_proxy ) < 1 ) {
+	if( ! job_ad->EvaluateAttrBool( ATTR_WANT_IO_PROXY, want_io_proxy ) ) {
+		want_io_proxy = false;
 		dprintf( D_FULLDEBUG, "JICShadow::initIOProxy(): "
-				 "Job does not define %s\n", ATTR_WANT_IO_PROXY );
-		want_io_proxy = 0;
+				 "Job does not define %s; setting to %s\n",
+				 ATTR_WANT_IO_PROXY, want_io_proxy ? "true" : "false" );
 	} else {
 		dprintf( D_ALWAYS, "Job has %s=%s\n", ATTR_WANT_IO_PROXY,
 				 want_io_proxy ? "true" : "false" );
 	}
-
-	if( want_io_proxy || job_universe==CONDOR_UNIVERSE_JAVA ) {
-		io_proxy_config_file.formatstr( "%s%cchirp.config",
-				 Starter->GetWorkingDir(), DIR_DELIM_CHAR );
-		if( !io_proxy.init(io_proxy_config_file.Value()) ) {
+	if (!enableFiles && want_io_proxy)
+	{
+		dprintf(D_ALWAYS, "Starter config prevents us from enabling IO proxy.\n");
+		want_io_proxy = false;
+	}
+	bool want_updates = want_io_proxy;
+	if ( ! job_ad->EvaluateAttrBool(ATTR_WANT_REMOTE_UPDATES, want_updates) ) {
+		want_updates = want_io_proxy;
+		dprintf(D_FULLDEBUG, "JICShadow::initIOProxy(): "
+				"Job does not define %s; setting to %s.\n",
+				ATTR_WANT_REMOTE_UPDATES, want_updates ? "true" : "false" );
+	} else {
+		dprintf(D_ALWAYS, "Job has %s=%s\n", ATTR_WANT_REMOTE_UPDATES,
+				want_updates ? "true" : "false");
+	}
+	if (!enableUpdates && want_updates)
+	{
+		dprintf(D_ALWAYS, "Starter config prevents us from enabling remote updates.\n");
+		want_updates = false;
+	}
+	bool want_delayed = true;
+	if ( ! job_ad->EvaluateAttrBool(ATTR_WANT_DELAYED_UPDATES, want_delayed) ) {
+		want_delayed = true;
+		dprintf(D_FULLDEBUG, "JICShadow::initIOProxy(): "
+				"Job does not define %s; enabling delayed updates.\n", ATTR_WANT_DELAYED_UPDATES);
+	} else {
+		dprintf(D_ALWAYS, "Job has %s=%s\n", ATTR_WANT_DELAYED_UPDATES,
+				want_delayed ? "true" : "false");
+	}
+	if (!enableDelayed && want_delayed)
+	{
+		dprintf(D_ALWAYS, "Starter config prevents us from enabling delayed updates.\n");
+		want_delayed = false;
+	}
+	dprintf(D_ALWAYS, "Chirp config summary: IO %s, Updates %s, Delayed updates %s.\n",
+		want_io_proxy ? "true" : "false", want_updates ? "true" : "false",
+		want_delayed ? "true" : "false");
+	if( want_io_proxy || want_updates || want_delayed || job_universe==CONDOR_UNIVERSE_JAVA ) {
+		m_wrote_chirp_config = true;
+		io_proxy_config_file.formatstr( "%s%c%s" ,
+				 Starter->GetWorkingDir(), DIR_DELIM_CHAR, CHIRP_CONFIG_FILENAME );
+		m_chirp_config_filename = io_proxy_config_file;
+		dprintf(D_FULLDEBUG, "Initializing IO proxy with config file at %s.\n", io_proxy_config_file.Value());
+		if( !io_proxy.init(this, io_proxy_config_file.Value(), want_io_proxy, want_updates, want_delayed) ) {
 			dprintf( D_FAILURE|D_ALWAYS, 
 					 "Couldn't initialize IO Proxy.\n" );
 			return false;
