@@ -57,7 +57,7 @@ void display_startup_info( const STARTUP_INFO *s, int flags );
 #undef ASSERT
 #define ASSERT(cond) \
 	if( !(cond) ) { \
-		EXCEPT( "Assertion ERROR on (%s)\n", #cond ); \
+		EXCEPT( "Assertion ERROR on (%s)", #cond ); \
 	} else {\
 		dprintf( D_FULLDEBUG, "Assertion Ok on (%s)\n", #cond ); \
 	}
@@ -880,7 +880,7 @@ proc_exit()
 		return NO_CORE;
 
 	  default:
-		EXCEPT( "Unexpected proc state (%d)\n", state );
+		EXCEPT( "Unexpected proc state (%d)", state );
 	}
 
 		// Can never get here.
@@ -993,7 +993,7 @@ update_cpu()
 UserProc *
 get_job_info()
 {
-	UserProc		*u_proc;
+	UserProc		*u_proc = NULL;
 	STARTUP_INFO	s;
 /*
 	int wait_for_debugger = 1;
@@ -1026,12 +1026,13 @@ get_job_info()
 			break;
 #endif
 		default:
-			if(s.cmd)
+			if(s.cmd) {
 				u_proc = new UserProc( s );
+				u_proc->display();
+			}
 			break;
 	}
 
-	u_proc->display();
 
 	// We need to clean up the memory allocated in the STARTUP_INFO I
 	// think that STARTUP_INFO should probably be a class with a
@@ -1192,7 +1193,8 @@ init_environment_info()
 		free(my_uid_domain);
 	}
 
-	ckptpltfrm = sysapi_ckptpltfrm();
+    ckptpltfrm = sysapi_ckptpltfrm();
+
 	/* don't forget one more for the NULL which needs to go over as well */
 	REMOTE_CONDOR_register_ckpt_platform( ckptpltfrm, strlen(ckptpltfrm) + 1);
 
