@@ -54,7 +54,6 @@ my @tests =
 			 #"EVENT_LOG_COUNT_EVENTS"	=> "FALSE",
 			 #"EVENT_LOG_MAX_ROTATIONS"	=> 1,
 			 #"EVENT_LOG_MAX_SIZE"		=> -1,
-			 #"MAX_EVENT_LOG"			=> 1000000,
 			 #"ENABLE_USERLOG_LOCKING"	=> "TRUE",
 			 "ENABLE_USERLOG_FSYNC"		=> "FALSE",
 		 },
@@ -70,7 +69,6 @@ my @tests =
 			 "EVENT_LOG_COUNT_EVENTS"	=> "FALSE",
 			 #"EVENT_LOG_MAX_ROTATIONS"	=> 0,
 			 "EVENT_LOG_MAX_SIZE"		=> 0,
-			 #"MAX_EVENT_LOG"			=> 0,
 			 "ENABLE_USERLOG_LOCKING"	=> "FALSE",
 			 "ENABLE_USERLOG_FSYNC"		=> "FALSE",
 		 },
@@ -85,7 +83,6 @@ my @tests =
 			 "EVENT_LOG_COUNT_EVENTS"	=> "FALSE",
 			 #"EVENT_LOG_MAX_ROTATIONS"	=> 0,
 			 "EVENT_LOG_MAX_SIZE"		=> 0,
-			 #"MAX_EVENT_LOG"			=> 0,
 			 "ENABLE_USERLOG_LOCKING"	=> "FALSE",
 			 "ENABLE_USERLOG_FSYNC"		=> "FALSE",
 		 },
@@ -99,8 +96,8 @@ my @tests =
 			 "EVENT_LOG"				=> "EventLog",
 			 "EVENT_LOG_COUNT_EVENTS"	=> "FALSE",
 			 #"EVENT_LOG_MAX_ROTATIONS"	=> 0,
-			 #"EVENT_LOG_MAX_SIZE"		=> 0,
-			 "MAX_EVENT_LOG"			=> 0,
+			 "EVENT_LOG_MAX_SIZE"		=> "",
+			 "MAX_EVENT_LOG"		=> 0,
 			 "ENABLE_USERLOG_LOCKING"	=> "FALSE",
 			 "ENABLE_USERLOG_FSYNC"		=> "FALSE",
 		 },
@@ -117,7 +114,6 @@ my @tests =
 			 "EVENT_LOG_COUNT_EVENTS"	=> "TRUE",
 			 "EVENT_LOG_MAX_ROTATIONS"	=> 1,
 			 "EVENT_LOG_MAX_SIZE"		=> 10000,
-			 #"MAX_EVENT_LOG"			=> -1,
 			 "ENABLE_USERLOG_LOCKING"	=> "FALSE",
 			 "ENABLE_USERLOG_FSYNC"		=> "FALSE",
 		 },
@@ -134,7 +130,6 @@ my @tests =
 			 "EVENT_LOG_COUNT_EVENTS"	=> "TRUE",
 			 "EVENT_LOG_MAX_ROTATIONS"	=> 2,
 			 "EVENT_LOG_MAX_SIZE"		=> 10000,
-			 #"MAX_EVENT_LOG"			=> -1,
 			 "ENABLE_USERLOG_LOCKING"	=> "FALSE",
 			 "ENABLE_USERLOG_FSYNC"		=> "FALSE",
 		 },
@@ -151,7 +146,6 @@ my @tests =
 			 "ENABLE_USERLOG_LOCKING"	=> "TRUE",
 			 "EVENT_LOG_MAX_ROTATIONS"	=> 5,
 			 "EVENT_LOG_MAX_SIZE"		=> 10000,
-			 #"MAX_EVENT_LOG"			=> -1,
 			 "ENABLE_USERLOG_FSYNC"		=> "FALSE",
 		 },
 		 auto				=> 1,
@@ -167,7 +161,6 @@ my @tests =
 			 "ENABLE_USERLOG_LOCKING"	=> "TRUE",
 			 "EVENT_LOG_MAX_ROTATIONS"	=> 20,
 			 "EVENT_LOG_MAX_SIZE"		=> 10000,
-			 #"MAX_EVENT_LOG"			=> -1,
 			 "ENABLE_USERLOG_FSYNC"		=> "FALSE",
 		 },
 		 auto				=> 1,
@@ -204,7 +197,6 @@ my @tests =
 			 "EVENT_LOG_COUNT_EVENTS"	=> "TRUE",
 			 "EVENT_LOG_MAX_ROTATIONS"	=> 0,
 			 #"EVENT_LOG_MAX_SIZE"		=> 10000,
-			 #"MAX_EVENT_LOG"			=> -1,
 			 "ENABLE_USERLOG_LOCKING"	=> "FALSE",
 			 "ENABLE_USERLOG_FSYNC"		=> "FALSE",
 		 },
