@@ -29,8 +29,14 @@
 #include "emit.h"
 #include "unit_test_utils.h"
 
+
+// IPV6_REMOVED - IPv6 changes obsoleted these interfaces.  However, 
+// these tests probably should be updated to the new interfaces,
+// so they are being kept here for nwo.
+#ifdef IPV6_REMOVED
 static bool test_normal_case(void);
 static bool test_alpha_input(void);
+#endif
 
 bool FTEST_string_to_sin(void) {
 		// beginning junk for getPortFromAddr(() {
@@ -41,13 +47,16 @@ bool FTEST_string_to_sin(void) {
 	
 		// driver to run the tests and all required setup
 	FunctionDriver driver;
+#ifdef IPV6_REMOVED
 	driver.register_function(test_normal_case);
 	driver.register_function(test_alpha_input);
+#endif
 	
 		// run the tests
 	return driver.do_all_functions();
 }
 
+#ifdef IPV6_REMOVED
 static bool test_normal_case() {
 	emit_test("Is normal input converted correctly?");
 	struct sockaddr_in sa_in;
@@ -89,3 +98,4 @@ static bool test_alpha_input() {
 	}
 	PASS;
 }
+#endif
