@@ -575,7 +575,7 @@ stats_histogram<T>& stats_histogram<T>::Accumulate(const stats_histogram<T>& sh)
 	// limits array as well, should we check that?)
 	if (this->cLevels != sh.cLevels) {
        #ifdef EXCEPT
-		EXCEPT("attempt to add histogram of %d items to histogram of %d items\n", 
+		EXCEPT("attempt to add histogram of %d items to histogram of %d items", 
 				sh.cLevels, this->cLevels);
        #else
         return *this;
@@ -584,7 +584,7 @@ stats_histogram<T>& stats_histogram<T>::Accumulate(const stats_histogram<T>& sh)
 
 	if (this->levels != sh.levels) {
        #ifdef EXCEPT
-		EXCEPT("Histogram level pointers are not the same.\n");
+		EXCEPT("Histogram level pointers are not the same.");
        #else
         return *this;
        #endif
@@ -605,7 +605,7 @@ stats_histogram<T>& stats_histogram<T>::operator=(const stats_histogram<T>& sh)
 		Clear();
 	} else if(this != &sh) {
 		if(this->cLevels > 0 && this->cLevels != sh.cLevels){
-			EXCEPT("Tried to assign different sized histograms\n");
+			EXCEPT("Tried to assign different sized histograms");
 			return *this;
 		} else if(this->cLevels == 0) {
 			this->cLevels = sh.cLevels;
@@ -618,7 +618,7 @@ stats_histogram<T>& stats_histogram<T>::operator=(const stats_histogram<T>& sh)
 			for(int i=0;i<=cLevels;++i){
 				this->data[i] = sh.data[i];
 				if(this->levels[i] < sh.levels[i] || this->levels[i] > sh.levels[i]){
-					EXCEPT("Tried to assign different levels of histograms\n");
+					EXCEPT("Tried to assign different levels of histograms");
 					return *this;	
 				}
 			}
@@ -684,7 +684,7 @@ int stats_histogram_ParseSizes(
          ++p;
 
       if ( ! is_digit(*p)) {
-         EXCEPT("Invalid input to ParseSizes at offset %d in '%s'\n", (int)(p-psz), psz);
+         EXCEPT("Invalid input to ParseSizes at offset %d in '%s'", (int)(p-psz), psz);
          break;
       }
 
@@ -729,7 +729,7 @@ int stats_histogram_ParseSizes(
 
 void stats_histogram_PrintSizes(MyString &  /*str*/, const  int64_t *  /*pSizes*/, int  /*cSizes*/)
 {
-   EXCEPT("stats_histogram::PrintSizes not implemented\n");
+   EXCEPT("stats_histogram::PrintSizes not implemented");
    // tj: WRITE THIS
 }
 
@@ -752,7 +752,7 @@ int stats_histogram_ParseTimes(
          ++p;
 
       if ( ! is_digit(*p)) {
-         EXCEPT("Invalid input to ParseTimes at offset %d in '%s'\n", (int)(p-psz), psz);
+         EXCEPT("Invalid input to ParseTimes at offset %d in '%s'", (int)(p-psz), psz);
          break;
       }
 
@@ -814,7 +814,7 @@ int stats_histogram_ParseTimes(
 
 void stats_histogram_times_PrintTimes(MyString &  /*str*/, const time_t *  /*pTimes*/, int /*cTimes*/)
 {
-   EXCEPT("stats_histogram::PrintTimes not implemented\n");
+   EXCEPT("stats_histogram::PrintTimes not implemented");
    // tj: WRITE THIS
 }
 
