@@ -111,10 +111,9 @@ activate_globus_gsi( void )
 	}
 */
 
-	if ( globus_thread_set_model( GLOBUS_THREAD_MODEL_NONE ) != GLOBUS_SUCCESS ) {
-		set_error_string( "couldn't set globus thread model" );
-		return -1;
-	}
+	// If this fails, it means something already configured a threaded
+	// model. That won't harm us, so ignore it.
+	globus_thread_set_model( GLOBUS_THREAD_MODEL_NONE );
 
 	if ( globus_module_activate(GLOBUS_GSI_CREDENTIAL_MODULE) ) {
 		set_error_string( "couldn't activate globus gsi credential module" );
