@@ -90,6 +90,7 @@ class UserLogFilesize_t : public UserLogInt64_t
 // ***************************
 WriteUserLog::WriteUserLog( bool disable_event_log )
 {
+	log_file_cache = NULL;
 	Reset( );
 	m_global_disable = disable_event_log;
 }
@@ -105,6 +106,7 @@ WriteUserLog::WriteUserLog (const char *owner,
 							int s,
 							bool xml)
 {
+	log_file_cache = NULL;
 	Reset( );
 	m_use_xml = xml;
 	
@@ -127,6 +129,7 @@ WriteUserLog::WriteUserLog (const char *owner,
 							int s,
 							bool xml)
 {
+	log_file_cache = NULL;
 	Reset( );
 	m_use_xml = xml;
 	
@@ -148,6 +151,7 @@ WriteUserLog::WriteUserLog (const char *owner,
 							bool xml,
 							const char *gjid)
 {
+	log_file_cache = NULL;
 	Reset();
 	m_use_xml = xml;
 
@@ -168,6 +172,7 @@ WriteUserLog::WriteUserLog (const char *owner,
 							bool xml,
 							const char *gjid)
 {
+	log_file_cache = NULL;
 	Reset();
 	m_use_xml = xml;
 
@@ -334,6 +339,9 @@ WriteUserLog::Configure( bool force )
 	m_enable_fsync = param_boolean( "ENABLE_USERLOG_FSYNC", true );
 	m_enable_locking = param_boolean( "ENABLE_USERLOG_LOCKING", true );
 
+	if ( m_global_disable ) {
+		return true;
+	}
 	m_global_path = param( "EVENT_LOG" );
 	if ( NULL == m_global_path ) {
 		return true;
