@@ -1,6 +1,7 @@
 #!/usr/bin/python
 
 import re
+import types
 import classad
 import datetime
 import unittest
@@ -73,6 +74,22 @@ class TestClassad(unittest.TestCase):
         ad["foo"] = classad.ExprTree('regexps("foo (bar)", "foo bar", "\\\\1")')
         self.assertEqual(ad.eval("foo"), "bar")
 
+    def test_list_conversion(self):
+        ad = dict(classad.ClassAd("[a = {1,2,3}]"))
+        self.assertTrue(isinstance(ad["a"], types.ListType))
+        self.assertTrue(isinstance(ad["a"][0], types.LongType))
+
+    def test_dict_conversion(self):
+        ad = classad.ClassAd({'a': [1,2, {}]})
+        dict_ad = dict(ad)
+        self.assertTrue(isinstance(dict_ad["a"][2], types.DictType))
+        self.assertEqual(classad.ClassAd(dict_ad).__repr__(), "[ a = { 1,2,[  ] } ]")
+        ad = classad.ClassAd("[a = [b = {1,2,3}]]")
+        inner_list = dict(ad)['a']['b']
+        self.assertTrue(isinstance(inner_list, types.ListType))
+        self.assertTrue(isinstance(inner_list[0], types.LongType))
+        self.assertTrue(isinstance(ad['a'], types.DictType))
+
     def test_ad_assignment(self):
         ad = classad.ClassAd()
         ad["foo"] = 2.1
@@ -161,11 +178,11 @@ class TestClassad(unittest.TestCase):
         self.assertEquals("baz", expr.eval())
 
     def test_abstime(self):
-        expr = classad.ExprTree('absTime("2013-09-12T07:50:23")')
+        expr = classad.ExprTree('absTime("2013-11-12T07:50:23")')
         dt = expr.eval()
         self.assertTrue(isinstance(dt, datetime.datetime))
         self.assertEquals(dt.year, 2013)
-        self.assertEquals(dt.month, 9)
+        self.assertEquals(dt.month, 11)
         self.assertEquals(dt.day, 12)
         self.assertEquals(dt.hour, 7)
         self.assertEquals(dt.minute, 50)
@@ -214,7 +231,7 @@ class TestClassad(unittest.TestCase):
 
     def test_subscript(self):
         ad = classad.ClassAd({'foo': [0,1,2,3]})
-        expr = classad.Attribute("foo")[2]
+        expr = classad.Attribute("foo")._get(2)
         self.assertTrue(isinstance(expr, classad.ExprTree))
         self.assertEquals(expr.eval(), classad.Value.Undefined)
         self.assertEquals(expr.eval(ad), 2)
